/**
*   Fira Sans
*/

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-Regular.woff);
    font-weight: normal;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-Medium.woff);
    font-weight: bold;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-Bold.woff);
    font-weight: bolder;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-Light.woff);
    font-weight: lighter;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-RegularItalic.woff);
    font-weight: normal;
    font-style: italic;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-MediumItalic.woff);
    font-weight: bold;
    font-style: italic;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-BoldItalic.woff);
    font-weight: bolder;
    font-style: italic;
}

@font-face
{
    font-family: FiraSans;
    src: url(../fonts/fira/FiraSans-LightItalic.woff);
    font-weight: lighter;
    font-style: italic;
}

/**
*   Fantasque
*/

@font-face
{
    font-family: Fantasque;
    src: url(../fonts/fantasque/FantasqueSansMono-Regular.woff);
    font-weight: normal;
}

@font-face
{
    font-family: Fantasque;
    src: url(../fonts/fantasque/FantasqueSansMono-Bold.woff);
    font-weight: bold;
}

@font-face
{
    font-family: Fantasque;
    src: url(../fonts/fantasque/FantasqueSansMono-RegItalic.woff);
    font-weight: normal;
    font-style: italic;
}

@font-face
{
    font-family: Fantasque;
    src: url(../fonts/fantasque/FantasqueSansMono-BoldItalic.woff);
    font-weight: bold;
    font-style: italic;
}